@@ -6,12 +6,14 @@ import asyncio
 import functools
 import json
 import logging
+import sys
 from contextlib import asynccontextmanager
 from typing import Generator, Optional
 
 import httpx
 import nbformat
 import orjson
+import websockets.exceptions
 from jupyter_client.utils import run_sync
 from nbclient.exceptions import CellExecutionError
 from nbformat import NotebookNode
@@ -111,6 +113,15 @@ class NoteableEngine(Engine):
         self.file = None
         self.job_instance_attempt: Optional[JobInstanceAttempt] = None
 
+        if kw.get("override_progress_bar", False):
+            from tqdm.auto import tqdm
+
+            # https://github.com/nteract/papermill/blob/54f6c038cdae0c70d5fb04691fa465e12aeb62cb/papermill/engines.py#L114 # noqa: E501
+            # file is set to stderr by default, but we want to use stdout, so we override it here
+            self.nb_man.pbar = tqdm(
+                total=len(self.nb.cells), unit="cell", desc="Executing", file=sys.stdout
+            )
+
     def catch_cell_metadata_updates(self, func):
         """A decorator for catching cell metadata updates related to papermill
         and updating the Noteable notebook via RTU"""
@@ -124,11 +135,18 @@ class NoteableEngine(Engine):
             for key, value in flatten_dict(
                 cell.metadata.papermill, parent_key_tuple=("papermill",)
             ).items():
-                run_sync(self.km.client.update_cell_metadata)(
-                    file=self.file,
-                    cell_id=cell.id,
-                    metadata_update_properties={"path": key, "value": value},
-                )
+                try:
+                    run_sync(self.km.client.update_cell_metadata)(
+                        file=self.file,
+                        cell_id=cell.id,
+                        metadata_update_properties={"path": key, "value": value},
+                    )
+                except (
+                    asyncio.exceptions.TimeoutError,
+                    websockets.exceptions.ConnectionClosedError,
+                ):
+                    logger.debug("Encountered an error while updating cell metadata")
+                    pass
             return ret_val
 
         return wrapper
@@ -320,7 +338,11 @@ class NoteableEngine(Engine):
         for key, value in flatten_dict(
             self.nb.metadata.papermill, parent_key_tuple=("papermill",)
         ).items():
-            await self.km.client.update_nb_metadata(self.file, {"path": key, "value": value})
+            try:
+                await self.km.client.update_nb_metadata(self.file, {"path": key, "value": value})
+            except (asyncio.exceptions.TimeoutError, websockets.exceptions.ConnectionClosedError):
+                logger.debug("Encountered an error while updating notebook metadata")
+                pass
 
     @staticmethod
     def create_kernel_manager(file: NotebookFile, client: NoteableClient, **kwargs):
@@ -358,9 +380,13 @@ class NoteableEngine(Engine):
     def _cell_exception(self, cell, cell_index=None, **kwargs):
         self.catch_cell_metadata_updates(self.nb_man.cell_exception)(cell, cell_index, **kwargs)
         # Manually update the Noteable nb metadata
-        run_sync(self.km.client.update_nb_metadata)(
-            self.file, {"path": ["papermill", "exception"], "value": True}
-        )
+        try:
+            run_sync(self.km.client.update_nb_metadata)(
+                self.file, {"path": ["papermill", "exception"], "value": True}
+            )
+        except (asyncio.exceptions.TimeoutError, websockets.exceptions.ConnectionClosedError):
+            logger.debug("Encountered an error while updating notebook metadata")
+            pass
 
     def _cell_complete(self, cell, cell_index=None, **kwargs):
         self.catch_cell_metadata_updates(self.nb_man.cell_complete)(cell, cell_index, **kwargs)
